@@ -42,10 +42,10 @@ class Repository:
 
         if model not in self.session:
             self.session.add(model)
-        else:
-            self.session.merge(model)
+        # else:
+        #     self.session.merge(model)
 
-        self.session.commit()
+        # self.session.commit()
 
         entity_type = type(model)
         Log.trace('Saved entity {0} with id {1}', entity_type, model.id)
