@@ -244,5 +244,11 @@ class Scraper:
     def switch_to(self, element: any) -> None:
         return self.on_switch_to(element=element)
 
+    def freeze(self) -> None:
+        self.on_freeze()
+
+    def unfreeze(self) -> None:
+        self.on_unfreeze()
+
     def close(self):
         self.on_close()
\ No newline at end of file
